@@ -293,8 +293,7 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
     gchar *query_text, *search_text, *location_uri, *downcase;
     GFile *location;
     GString *sparql;
-    GList *mimetypes, *l;
-    gint mime_count;
+    g_autoptr (GPtrArray) mimetypes = NULL;
     GPtrArray *date_range;
 
     tracker = NAUTILUS_SEARCH_ENGINE_TRACKER (provider);
@@ -327,7 +326,6 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
     location = nautilus_query_get_location (tracker->query);
     location_uri = location ? g_file_get_uri (location) : NULL;
     mimetypes = nautilus_query_get_mime_types (tracker->query);
-    mime_count = g_list_length (mimetypes);
 
     sparql = g_string_new ("SELECT DISTINCT nie:url(?urn) fts:rank(?urn) nfo:fileLastModified(?urn) nfo:fileLastAccessed(?urn)");
 
@@ -349,7 +347,7 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
         g_string_append_printf (sparql, "; fts:match '\"%s\"*'", search_text);
     }
 
-    if (mime_count > 0)
+    if (mimetypes->len > 0)
     {
         g_string_append (sparql, "; nie:mimeType ?mime");
     }
@@ -409,19 +407,19 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
         g_ptr_array_unref (date_range);
     }
 
-    if (mime_count > 0)
+    if (mimetypes->len > 0)
     {
         g_string_append (sparql, " && (");
 
-        for (l = mimetypes; l != NULL; l = l->next)
+        for (gint i = 0; i < mimetypes->len; i++)
         {
-            if (l != mimetypes)
+            if (i != 0)
             {
                 g_string_append (sparql, " || ");
             }
 
             g_string_append_printf (sparql, "fn:contains(?mime, '%s')",
-                                    (gchar *) l->data);
+                                    (gchar *) g_ptr_array_index (mimetypes, i));
         }
         g_string_append (sparql, ")\n");
     }
@@ -438,7 +436,6 @@ nautilus_search_engine_tracker_start (NautilusSearchProvider *provider)
 
     g_free (search_text);
     g_free (location_uri);
-    g_list_free_full (mimetypes, g_free);
     g_object_unref (location);
 }
 
